@@ -138,7 +138,7 @@ Puppet::Type.newtype(:vs_port) do
     desc "Allowed VLAN ids on this port.
 
       This parameter is only meaningful for no access ports. Ports in native-tagged or
-      native-untagged mode allways allow their native VLAN id.
+      native-untagged mode always allow their native VLAN id.
 
       VLAN ids may be specified as a list of integers. Defaults to []."
 
@@ -180,4 +180,8 @@ Puppet::Type.newtype(:vs_port) do
   autorequire(:vs_bridge) do
     self[:bridge] if self[:bridge]
   end
+
+  autorequire(:service) do
+    ['openvswitch']
+  end
 end
